
# Slot: text




URI: [linkml:text](https://w3id.org/linkml/text)


## Domain and Range

[PermissibleValue](PermissibleValue.md) &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [PermissibleValue](PermissibleValue.md)
